/*
 * Copyright 2010-2017 Restlet S.A.S. All rights reserved.
 * Restlet is registered trademark of Restlet S.A.S.
 */

import { DOMParser } from 'xmldom';
import xpath from 'xpath';

export function evaluateXpath(xpathSelector, xmlAsString) {
  return xpath.evaluate(
    xpathSelector,
    new DOMParser().parseFromString(xmlAsString),
    null,                       // namespaceResolver
    xpath.XPathResult.ANY_TYPE, // resultType
    null
  );
}

export function evaluateXpathWithRhino(xpathSelector, xmlAsString) {
  const result = evaluateXpath(xpathSelector, xmlAsString);

  let resultType;
  switch (result.resultType) {
    case 0:
      resultType = 'Any';
      break;
    case 1:
      resultType = 'Number';
      break;
    case 2:
      resultType = 'String';
      break;
    case 3:
      resultType = 'Boolean';
      break;
    case 4:
      resultType = 'UnorderedNodeIterator';
      break;
    case 5:
      resultType = 'OrderedNodeIterator';
      break;
    case 6:
      resultType = 'UnorderedNodeSnapshot';
      break;
    case 7:
      resultType = 'OrderedNodeSnapshot';
      break;
    case 8:
      resultType = 'AnyUnorderedNode';
      break;
    case 9:
      resultType = 'FirstOrderedNode';
      break;

    default:
      throw new Error(`Unsupported XPath result type ${result.resultType}`);
  }

  return JSON.stringify({
    resultType: resultType,
    booleanValue: result.booleanValue,
    stringValue: result.stringValue,
    numberValue: result.numberValue,
    matchingNodes: result.nodes ?
      result.nodes.map(n => {
        return {
          name: n.name,
          stringValue: n.toString()
        };
      }) :
      []
  });
}
